summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJames Zern <jzern@google.com>2022-12-15 18:11:40 -0800
committerJames Zern <jzern@google.com>2022-12-15 18:11:40 -0800
commited92a62649f77c60dbc107c3a486f9c008a261a3 (patch)
tree0328057ca6fa914036e69f48775fd68f3b42bc92
parent1d58575b18c63c400f4be9dbfd11ee4e74e3c0a5 (diff)
downloadlibwebp-ed92a62649f77c60dbc107c3a486f9c008a261a3.tar.gz
extras: WebpToSDL -> WebPToSDL
this normalizes the function case to what's more commonly used in the project Change-Id: If614cb8eff4afba96b2468e28c52d850651a759b
-rw-r--r--CMakeLists.txt4
-rw-r--r--extras/vwebp_sdl.c2
-rw-r--r--extras/webp_to_sdl.c2
-rw-r--r--extras/webp_to_sdl.h4
-rw-r--r--webp_js/index.html2
-rw-r--r--webp_js/index_wasm.html2
6 files changed, 8 insertions, 8 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 4add686d..0a5af428 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -649,7 +649,7 @@ if(WEBP_BUILD_WEBP_JS)
set_target_properties(
webp_js
PROPERTIES LINK_FLAGS "-sWASM=0 \
- -sEXPORTED_FUNCTIONS=_WebpToSDL -sINVOKE_RUN=0 \
+ -sEXPORTED_FUNCTIONS=_WebPToSDL -sINVOKE_RUN=0 \
-sEXPORTED_RUNTIME_METHODS=cwrap")
set_target_properties(webp_js PROPERTIES OUTPUT_NAME webp)
target_compile_definitions(webp_js PUBLIC EMSCRIPTEN WEBP_HAVE_SDL)
@@ -662,7 +662,7 @@ if(WEBP_BUILD_WEBP_JS)
set_target_properties(
webp_wasm
PROPERTIES LINK_FLAGS "-sWASM=1 \
- -sEXPORTED_FUNCTIONS=_WebpToSDL -sINVOKE_RUN=0 \
+ -sEXPORTED_FUNCTIONS=_WebPToSDL -sINVOKE_RUN=0 \
-sEXPORTED_RUNTIME_METHODS=cwrap")
target_compile_definitions(webp_wasm PUBLIC EMSCRIPTEN WEBP_HAVE_SDL)
diff --git a/extras/vwebp_sdl.c b/extras/vwebp_sdl.c
index 3cf44666..e9554eb1 100644
--- a/extras/vwebp_sdl.c
+++ b/extras/vwebp_sdl.c
@@ -75,7 +75,7 @@ int main(int argc, char* argv[]) {
fprintf(stderr, "File too large.\n");
goto Error;
}
- ok = WebpToSDL((const char*)webp, (int)webp_size);
+ ok = WebPToSDL((const char*)webp, (int)webp_size);
free((void*)webp);
if (!ok) {
WFPRINTF(stderr, "Error decoding file %s\n", (const W_CHAR*)file);
diff --git a/extras/webp_to_sdl.c b/extras/webp_to_sdl.c
index b13fc928..1e526811 100644
--- a/extras/webp_to_sdl.c
+++ b/extras/webp_to_sdl.c
@@ -29,7 +29,7 @@
#endif
static int init_ok = 0;
-int WebpToSDL(const char* data, unsigned int data_size) {
+int WebPToSDL(const char* data, unsigned int data_size) {
int ok = 0;
VP8StatusCode status;
WebPDecoderConfig config;
diff --git a/webp_js/index.html b/webp_js/index.html
index 10873a98..33cacb4c 100644
--- a/webp_js/index.html
+++ b/webp_js/index.html
@@ -18,7 +18,7 @@
var WebpToCanvas;
function init() {
- WebpToCanvas = Module.cwrap('WebpToSDL', 'number', ['array', 'number']);
+ WebpToCanvas = Module.cwrap('WebPToSDL', 'number', ['array', 'number']);
}
window.onload = init;
diff --git a/webp_js/index_wasm.html b/webp_js/index_wasm.html
index b77c22c4..5d7c17e8 100644
--- a/webp_js/index_wasm.html
+++ b/webp_js/index_wasm.html
@@ -34,7 +34,7 @@ function decode(webp_data, canvas_id) {
var result;
if (Module["asm"] != undefined) {
// wrapper for the function decoding a WebP into a canvas object
- WebpToCanvas = Module.cwrap('WebpToSDL', 'number', ['array', 'number']);
+ WebpToCanvas = Module.cwrap('WebPToSDL', 'number', ['array', 'number']);
// get the canvas to decode into
var canvas = document.getElementById(canvas_id);
if (canvas == null) return;
diff --git a/extras/webp_to_sdl.h b/extras/webp_to_sdl.h
index 1b5ea980..1534f2b4 100644
--- a/extras/webp_to_sdl.h
+++ b/extras/webp_to_sdl.h
@@ -14,9 +14,9 @@
#ifndef WEBP_EXTRAS_WEBP_TO_SDL_H_
#define WEBP_EXTRAS_WEBP_TO_SDL_H_
// Exports the method WebpToSDL(const char* data, int data_size) which decodes
// a WebP bitstream into an RGBA SDL surface.
// Return false on failure.
-extern int WebpToSDL(const char* data, unsigned int data_size);
+extern int WebPToSDL(const char* data, unsigned int data_size);
#endif // WEBP_EXTRAS_WEBP_TO_SDL_H_
@@ -14,9 +14,9 @@
#ifndef WEBP_EXTRAS_WEBP_TO_SDL_H_
#define WEBP_EXTRAS_WEBP_TO_SDL_H_
-// Exports the method WebpToSDL(const char* data, int data_size) which decodes
+// Exports the method WebPToSDL(const char* data, int data_size) which decodes
// a WebP bitstream into an RGBA SDL surface.
// Return false on failure.